==> activity-center-biz-1.0.2-20160701.054452-45-sources.jar: cn/com/duiba/activity/center/biz/entity/game/DuibaQuestionAnswerEntity.java <==
package cn.com.duiba.activity.center.biz.entity.game;

import java.io.Serializable;
import java.util.Date;

public class DuibaQuestionAnswerEntity implements Serializable {
	private static final long serialVersionUID = -5549926885474801061L;

	private Long id;
	private String title;
	private Integer status;
	private Long creditsPrice;
	private Integer limitCount;
	private String limitScope;
	private Integer freeLimit;
	private String freeScope;
	private Long duibaQuestionAnswerBrickId;
	private String rule;
	private String banner;
	private String smallImage;
	private String whiteImage;
	private String logo;
	private String recommendImage;
	private String selectQuestionBank;
	private Integer questionNum;
	private Integer switches;
	private Date autoOffDate;
	private Boolean deleted;
	private Date gmtCreate;
	private Date gmtModified;
	private String freeRule;

	public DuibaQuestionAnswerEntity(){

	}

	public DuibaQuestionAnswerEntity(Long id){
		this.id = id;
		this.gmtModified = new Date();
	}
	
	public void openSwitch(int s) {
		int v = 1 << s;
		switches = switches | v;
	}

	public void closeSwitch(int s) {
		int v = 1 << s;
		v = ~v;
		switches = switches & v;
	}

	public boolean isOpenSwitch(int s) {
		int v = 1 << s;
		int ret = switches & v;
		return ret != 0;
	}
	
	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public String getTitle() {
		return title;
	}
	public void setTitle(String title) {
		this.title = title;
	}
	public Integer getStatus() {
		return status;
	}
	public void setStatus(Integer status) {
		this.status = status;
	}
	public Long getCreditsPrice() {
		return creditsPrice;
	}
	public void setCreditsPrice(Long creditsPrice) {
		this.creditsPrice = creditsPrice;
	}
	public Integer getLimitCount() {
		return limitCount;
	}
	public void setLimitCount(Integer limitCount) {
		this.limitCount = limitCount;
	}
	public String getLimitScope() {
		return limitScope;
	}
	public void setLimitScope(String limitScope) {
		this.limitScope = limitScope;
	}
	public Integer getFreeLimit() {
		return freeLimit;
	}
	public void setFreeLimit(Integer freeLimit) {
		this.freeLimit = freeLimit;
	}
	public String getFreeScope() {
		return freeScope;
	}
	public void setFreeScope(String freeScope) {
		this.freeScope = freeScope;
	}
	public Long getDuibaQuestionAnswerBrickId() {
		return duibaQuestionAnswerBrickId;
	}
	public void setDuibaQuestionAnswerBrickId(Long duibaQuestionAnswerBrickId) {
		this.duibaQuestionAnswerBrickId = duibaQuestionAnswerBrickId;
	}
	public String getRule() {
		return rule;
	}
	public void setRule(String rule) {
		this.rule = rule;
	}
	public String getBanner() {
		return banner;
	}
	public void setBanner(String banner) {
		this.banner = banner;
	}
	public String getSmallImage() {
		return smallImage;
	}
	public void setSmallImage(String smallImage) {
		this.smallImage = smallImage;
	}
	public String getWhiteImage() {
		return whiteImage;
	}
	public void setWhiteImage(String whiteImage) {
		this.whiteImage = whiteImage;
	}
	public String getLogo() {
		return logo;
	}
	public void setLogo(String logo) {
		this.logo = logo;
	}
	public String getRecommendImage() {
		return recommendImage;
	}
	public void setRecommendImage(String recommendImage) {
		this.recommendImage = recommendImage;
	}
	public String getSelectQuestionBank() {
		return selectQuestionBank;
	}
	public void setSelectQuestionBank(String selectQuestionBank) {
		this.selectQuestionBank = selectQuestionBank;
	}
	public Integer getQuestionNum() {
		return questionNum;
	}
	public void setQuestionNum(Integer questionNum) {
		this.questionNum = questionNum;
	}
	public Integer getSwitches() {
		return switches;
	}
	public void setSwitches(Integer switches) {
		this.switches = switches;
	}
	public Date getAutoOffDate() {
		return autoOffDate;
	}
	public void setAutoOffDate(Date autoOffDate) {
		this.autoOffDate = autoOffDate;
	}
	public Boolean getDeleted() {
		return deleted;
	}
	public void setDeleted(Boolean deleted) {
		this.deleted = deleted;
	}
	public Date getGmtCreate() {
		return gmtCreate;
	}
	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}
	public Date getGmtModified() {
		return gmtModified;
	}
	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}

	public String getFreeRule() {
		return freeRule;
	}

	public void setFreeRule(String freeRule) {
		this.freeRule = freeRule;
	}
}

==> activity-center-biz-1.0.2-20160706.034119-56-sources.jar: cn/com/duiba/activity/center/biz/entity/game/DuibaQuestionAnswerEntity.java <==
package cn.com.duiba.activity.center.biz.entity.game;

import java.io.Serializable;
import java.util.Date;

public class DuibaQuestionAnswerEntity implements Serializable {
	private static final long serialVersionUID = -5549926885474801061L;

	private Long id;
	private String title;
	private Integer status;
	private Long creditsPrice;
	private Integer limitCount;
	private String limitScope;
	private Integer freeLimit;
	private String freeScope;
	private Long duibaQuestionAnswerBrickId;
	private String rule;
	private String banner;
	private String smallImage;
	private String whiteImage;
	private String logo;
	private String recommendImage;
	private String selectQuestionBank;
	private Integer questionNum;
	private Integer switches;
	private Date autoOffDate;
	private Boolean deleted;
	private Date gmtCreate;
	private Date gmtModified;
	private String freeRule;
	private Long activityCategoryId;//活动分类

	public DuibaQuestionAnswerEntity(){

	}

	public DuibaQuestionAnswerEntity(Long id){
		this.id = id;
		this.gmtModified = new Date();
	}
	
	public void openSwitch(int s) {
		int v = 1 << s;
		switches = switches | v;
	}

	public void closeSwitch(int s) {
		int v = 1 << s;
		v = ~v;
		switches = switches & v;
	}

	public boolean isOpenSwitch(int s) {
		int v = 1 << s;
		int ret = switches & v;
		return ret != 0;
	}
	
	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public String getTitle() {
		return title;
	}
	public void setTitle(String title) {
		this.title = title;
	}
	public Integer getStatus() {
		return status;
	}
	public void setStatus(Integer status) {
		this.status = status;
	}
	public Long getCreditsPrice() {
		return creditsPrice;
	}
	public void setCreditsPrice(Long creditsPrice) {
		this.creditsPrice = creditsPrice;
	}
	public Integer getLimitCount() {
		return limitCount;
	}
	public void setLimitCount(Integer limitCount) {
		this.limitCount = limitCount;
	}
	public String getLimitScope() {
		return limitScope;
	}
	public void setLimitScope(String limitScope) {
		this.limitScope = limitScope;
	}
	public Integer getFreeLimit() {
		return freeLimit;
	}
	public void setFreeLimit(Integer freeLimit) {
		this.freeLimit = freeLimit;
	}
	public String getFreeScope() {
		return freeScope;
	}
	public void setFreeScope(String freeScope) {
		this.freeScope = freeScope;
	}
	public Long getDuibaQuestionAnswerBrickId() {
		return duibaQuestionAnswerBrickId;
	}
	public void setDuibaQuestionAnswerBrickId(Long duibaQuestionAnswerBrickId) {
		this.duibaQuestionAnswerBrickId = duibaQuestionAnswerBrickId;
	}
	public String getRule() {
		return rule;
	}
	public void setRule(String rule) {
		this.rule = rule;
	}
	public String getBanner() {
		return banner;
	}
	public void setBanner(String banner) {
		this.banner = banner;
	}
	public String getSmallImage() {
		return smallImage;
	}
	public void setSmallImage(String smallImage) {
		this.smallImage = smallImage;
	}
	public String getWhiteImage() {
		return whiteImage;
	}
	public void setWhiteImage(String whiteImage) {
		this.whiteImage = whiteImage;
	}
	public String getLogo() {
		return logo;
	}
	public void setLogo(String logo) {
		this.logo = logo;
	}
	public String getRecommendImage() {
		return recommendImage;
	}
	public void setRecommendImage(String recommendImage) {
		this.recommendImage = recommendImage;
	}
	public String getSelectQuestionBank() {
		return selectQuestionBank;
	}
	public void setSelectQuestionBank(String selectQuestionBank) {
		this.selectQuestionBank = selectQuestionBank;
	}
	public Integer getQuestionNum() {
		return questionNum;
	}
	public void setQuestionNum(Integer questionNum) {
		this.questionNum = questionNum;
	}
	public Integer getSwitches() {
		return switches;
	}
	public void setSwitches(Integer switches) {
		this.switches = switches;
	}
	public Date getAutoOffDate() {
		return autoOffDate;
	}
	public void setAutoOffDate(Date autoOffDate) {
		this.autoOffDate = autoOffDate;
	}
	public Boolean getDeleted() {
		return deleted;
	}
	public void setDeleted(Boolean deleted) {
		this.deleted = deleted;
	}
	public Date getGmtCreate() {
		return gmtCreate;
	}
	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}
	public Date getGmtModified() {
		return gmtModified;
	}
	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}

	public String getFreeRule() {
		return freeRule;
	}

	public void setFreeRule(String freeRule) {
		this.freeRule = freeRule;
	}

    public Long getActivityCategoryId() {
        return activityCategoryId;
    }

    public void setActivityCategoryId(Long activityCategoryId) {
        this.activityCategoryId = activityCategoryId;
    }
}
